SupportedFileType

Struct SupportedFileType 

pub struct SupportedFileType {
    pub name: String,
    pub magic: Vec<String>,
    pub is_executable: bool,
    pub description: Option<String>,
}
Information about a file type supported by Malware DB

Fields

name: String

Common name of the file type

magic: Vec<String>

Magic number bytes in hex of the file type

is_executable: bool

Whether the file type is executable

description: Option<String>

Description of the file type

Implementations

Source

impl SupportedFileType

pub fn __repr__(&self) -> String

Supported file type as a printable representation

pub fn __str__(&self) -> String

Supported file type as a printable simpler representation